"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const rabbitmq_consumer_setup_error_1 = require("../errors/rabbitmq-consumer-setup.error");
const consumer_1 = require("../models/consumer");
class ConsumerFactory {
    constructor(connection) {
        this.connection = connection;
    }
    setConfigs(configs) {
        this.configs = configs;
    }
    setCustomSetupFunction(setupFunction) {
        this.customSetupFunction = setupFunction;
    }
    newConsumer() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const consumer = new consumer_1.Consumer();
                if (!this.customSetupFunction && !this.configs)
                    throw new Error('Either custom consumer setup function or configs must be provided');
                if (this.customSetupFunction)
                    consumer.setCustomSetupFunction(this.customSetupFunction);
                else
                    consumer.setConfigs(this.configs);
                yield consumer.init(this.connection);
                return consumer;
            }
            catch (err) {
                throw new rabbitmq_consumer_setup_error_1.RabbitMqConsumerSetupError(err.message);
            }
        });
    }
}
exports.ConsumerFactory = ConsumerFactory;
//# sourceMappingURL=consumer-factory.js.map