"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const rabbitmq_publisher_setup_error_1 = require("../errors/rabbitmq-publisher-setup.error");
const publisher_1 = require("../models/publisher");
class PublisherFactory {
    constructor(connection) {
        this.connection = connection;
    }
    setConfigs(configs) {
        this.configs = configs;
    }
    setCustomSetupFunction(setupFunction) {
        this.setupFunction = setupFunction;
    }
    newPublisher() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const publisher = new publisher_1.Publisher();
                if (this.setupFunction) {
                    publisher.setCustomSetupFunction(this.setupFunction);
                    yield publisher.init(this.connection);
                }
                else {
                    publisher.setConfigs(this.configs);
                    yield publisher.init(this.connection);
                }
                return publisher;
            }
            catch (err) {
                throw new rabbitmq_publisher_setup_error_1.RabbitMqPublisherSetupError(err.message);
            }
        });
    }
}
exports.PublisherFactory = PublisherFactory;
//# sourceMappingURL=publisher-factory.js.map