"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const amqp = require("amqplib");
const rabbitmq_connection_error_1 = require("../errors/rabbitmq-connection.error");
const rabbitmq_connection_1 = require("../models/rabbitmq-connection");
class RabbitMqConnectionFactory {
    constructor() { }
    setUri(uri) {
        this.uri = uri;
    }
    setOptions(options) {
        this.options = options;
    }
    newConnection() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (!this.options && !this.uri)
                    throw new Error('Either options or connection uri must be provided');
                const amqpConnection = yield amqp.connect(this.options || this.uri);
                return new rabbitmq_connection_1.RabbitMqConnection(amqpConnection, this.options || this.uri);
            }
            catch (error) {
                throw new rabbitmq_connection_error_1.RabbitMqConnectionError(`Error while building connection to RabbitMQ: ${error.message}`, error.code);
            }
        });
    }
}
exports.RabbitMqConnectionFactory = RabbitMqConnectionFactory;
//# sourceMappingURL=rabbit-mq-connection-factory.js.map